/* help.h: help messages for web2c programs.

   This is included by everyone, from cpascal.h.  This is better than
   putting the help messages directly in the change files because (1)
   multiline strings aren't supported by tangle, and it would be a pain
   to make up a new syntax for them in web2c, and (2) when a help msg
   changes, we need only recompile, not retangle or reconvert.  The
   downside is that everything gets recompiled when any msg changes, but
   that's better than having umpteen separate tiny files.  (For one
   thing, the messages have a lot in common, so it's nice to have them
   in one place.)

Copyright (C) 1995, 96 Karl Berry, 1997 John Plaice and Yannis Haralambous

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */

#ifndef HELP_H
#define HELP_H

#ifdef Omega
#define OMEGAHELP \
"Usage: omega [OPTION]... [TEXNAME[.tex]] [COMMANDS]\n\
   or: omega [OPTION]... \\FIRST-LINE\n\
   or: omega [OPTION]... &FMT ARGS\n\
  Run Omega on TEXNAME, usually creating TEXNAME.dvi.\n\
  Any remaining COMMANDS are processed as Omega input, after TEXNAME is read.\n\
  If the first line of TEXNAME is %&FMT, and FMT is an existing .fmt file,\n\
  use it; %&ini means iniomega.  Else use `NAME.fmt', where NAME is the\n\
  program invocation name, most commonly `omega'.\n\
\n\
  Alternatively, if the first non-option argument begins with a backslash,\n\
  interpret all non-option arguments as a line of Omega input.\n\
\n\
  Alternatively, if the first non-option argument begins with a &, the\n\
  next word is taken as the FMT to read, overriding all else.  Any\n\
  remaining arguments are processed as above.\n\
\n\
  If no arguments or options are specified, prompt for input.\n\
\n\
-extend-jobname=WHEN     remove suffix from \\jobname (WHEN=always/never)\n\
-fmt=FMTNAME             use FMTNAME instead of program name or a %& line\n\
-ini                     be iniomega, for dumping formats; this is implicitly\n\
                         true if the program name is `iniomega'\n\
-kpathsea-debug=NUMBER   set path searching debugging flags according to\n\
                         the bits of NUMBER\n\
[-no]-maketex=FMT        disable/enable MakeTeXFMT generation (FMT=tex/tfm)\n\
-output-comment=STRING   use STRING for DVI file comment instead of date\n\
-progname=STRING         set program (and fmt) name to STRING\n\
-shell-escape            enable \\write18{SHELL COMMAND}\n\
-help                    display this help and exit\n\
-version                 output version information and exit\n"
#ifdef IPC
#define TEX_IPC_HELP \
"-ipc            send dvi output to a socket as well as the usual output file\n\
-ipc-start      as with -ipc, and also start the server at the other end\n"
#endif /* IPC */
#endif /* Omega */

#ifdef ODVICOPY
#define ODVICOPYHELP \
"Usage: odvicopy [OPTION]... [INDVI[.dvi] [OUTDVI[.dvi]]]\n\
  Expand virtual font references in INDVI to OUTDVI.\n\
  Defaults are standard input and standard output, respectively.\n\
\n\
-magnification=NUMBER  override existing magnification with NUMBER\n\
-max-pages=NUMBER      process NUMBER pages; default one million\n\
-page-start=PAGE-SPEC  start at PAGE-SPEC, for example `2' or `5.*.-2'\n\
-help                  display this help and exit\n\
-version               output version information and exit\n"
#endif /* ODVICOPY */

#ifdef ODVITYPE
#define ODVITYPEHELP \
"Usage: odvitype [OPTION]... DVIFILE[.dvi]\n\
  Verify and translate DVIFILE to human-readable form,\n\
  written to standard output.\n\
\n\
-dpi=REAL              set resolution to REAL pixels per inch; default 300.0\n\
-magnification=NUMBER  override existing magnification with NUMBER\n\
-max-pages=NUMBER      process NUMBER pages; default one million\n\
-output-level=NUMBER   verbosity level, from 0 to 4; default 4\n\
-page-start=PAGE-SPEC  start at PAGE-SPEC, for example `2' or `5.*.-2'\n\
-show-opcodes          show numeric opcodes (in decimal)\n\
-help                  display this help and exit\n\
-version               output version information and exit\n"
#endif /* ODVITYPE */

#ifdef OFM2OPL
#define OFM2OPLHELP \
"Usage: ofm2opl [OPTION]... OFMNAME[.ofm] [OPLFILE[.opl]]\n\
  Translate the font metrics OFMNAME to human-readable property list file\n\
  OPLFILE or standard output.\n\
\n\
-charcode-format=TYPE  output character codes according to TYPE,\n\
                        either `hex' or `ascii'; default is hex,\n\
                        ascii = ascii letters and digits, hex for all else\n\
-help                  display this help and exit\n\
-verbose               display progress reports\n\
-version               output version information and exit\n"
#endif /* OFM2OPL */

#ifdef OPL2OFM
#define OPL2OFMHELP \
"Usage: opl2ofm [OPTION]... OPLFILE[.opl] [OFMFILE[.ofm]]\n\
  Translate the property list OPLFILE to OFMFILE.\n\
  Default OFMFILE is basename of OPLFILE extended with `.ofm'.\n\
\n\
-help       display this help and exit\n\
-verbose    display progress reports\n\
-version    output version information and exit\n"
#endif /* OPL2OFM */

#ifdef OVF2OVP
#define OVF2OVPHELP \
"Usage: ovf2ovp [OPTION]... OVFNAME[.ovf] [OFMNAME[.ofm] [OVPFILE[.ovp]]]\n\
  Translate OVFNAME and companion OFMNAME to human-readable\n\
  virtual property list file OVPFILE or standard output.\n\
  If OFMNAME is not specified, OVFNAME (with `.ovf' removed) is used.\n\
\n\
-charcode-format=TYPE  output character codes according to TYPE,\n\
                        either `hex' or `ascii'; default is hex,\n\
                        ascii = ascii letters and digits, hex for all else\n\
-help                  display this help and exit\n\
-verbose               display progress reports\n\
-version               output version information and exit\n"
#endif /* OVF2OVP */

#ifdef OVP2OVF
#define OVP2OVFHELP \
"Usage: ovp2ovf [OPTION]... OVPFILE[.ovp] [OVFFILE[.ovf] [OFMFILE[.ofm]]]\n\
  Translate OVPFILE to OVFFILE and companion OFMFILE.\n\
  Default OVFFILE is basename of OVPFILE extended with `.ovf'.\n\
  Default OFMFILE is OVFFILE extended with `.ofm'.\n\
\n\
-help                  display this help and exit\n\
-verbose               display progress reports\n\
-version               output version information and exit\n"
#endif /* OVP2OVF */

#if defined (OTANGLE) || defined (OTANGLEBOOT)
#define OTANGLEHELP \
"Usage: otangle [OPTION]... WEBFILE[.web] [CHANGEFILE[.ch]]\n\
  Otangle WEBFILE with CHANGEFILE into a Pascal program.\n\
  Default CHANGEFILE is /dev/null;\n\
  Pascal output goes to the basename of WEBFILE extended with `.p',\n\
  and a string pool file, if necessary, to the same extended with `.pool'.\n\
\n\
-help       display this help and exit\n\
-version    output version information and exit\n"
#endif /* OTANGLE */

#if defined (TANGLE) || defined (TANGLEBOOT)
#define TANGLEHELP \
"Usage: tangle [OPTION]... WEBFILE[.web] [CHANGEFILE[.ch]]\n\
  Tangle WEBFILE with CHANGEFILE into a Pascal program.\n\
  Default CHANGEFILE is /dev/null;\n\
  Pascal output goes to the basename of WEBFILE extended with `.p',\n\
  and a string pool file, if necessary, to the same extended with `.pool'.\n\
\n\
-help       display this help and exit\n\
-version    output version information and exit\n"
#endif /* TANGLE */

#endif /* not HELP_H */
